==> maxdb-source-7_6_00_27.zip: V76_00_27/MaxDB_ORG/sys/src/SAPDB/ToolsCommon/Parsers/SyntaxElements/ToolsParsersSyntEl_Headers.hpp <==
/*!
    \file    ToolsParsersSyntEl_Headers.hpp
    \author  TiloH
    \ingroup backup tool simulators for tests
    \brief   declaring a parser for parameters

    ========== licence begin  GPL
    Copyright (c) 1998-2005 SAP AG

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end


*/

#if !defined(ToolsParsersSyntEl_Headers_HPP)
#define ToolsParsersSyntEl_Headers_HPP

#include "ToolsCommon/Parsers/SyntaxElements/ToolsParsersSyntEl_AlternativeList.hpp"
#include "ToolsCommon/Parsers/SyntaxElements/ToolsParsersSyntEl_Concatenation.hpp"
#include "ToolsCommon/Parsers/SyntaxElements/ToolsParsersSyntEl_Keyword.hpp"
#include "ToolsCommon/Parsers/SyntaxElements/ToolsParsersSyntEl_MultipleValueVariable.hpp"
#include "ToolsCommon/Parsers/SyntaxElements/ToolsParsersSyntEl_Option.hpp"
#include "ToolsCommon/Parsers/SyntaxElements/ToolsParsersSyntEl_ParameterGroup.hpp"
#include "ToolsCommon/Parsers/SyntaxElements/ToolsParsersSyntEl_Repetition.hpp"
#include "ToolsCommon/Parsers/SyntaxElements/ToolsParsersSyntEl_Set.hpp"
#include "ToolsCommon/Parsers/SyntaxElements/ToolsParsersSyntEl_Variable.hpp"

#endif

==> maxdb-source-7_6_00_37.zip: V76_00_37/MaxDB_ORG/sys/src/SAPDB/ToolsCommon/Parsers/SyntaxElements/ToolsParsersSyntEl_Headers.hpp <==
/*!
    \file    ToolsParsersSyntEl_Headers.hpp
    \author  TiloH
    \ingroup syntax elements for parsers
    \brief   header of headers for the syntax elements

    ========== licence begin  GPL
    Copyright (c) 1998-2006 SAP AG

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end

*/

#if !defined(TOOLSPARSERSSYNTEL_HEADERS_HPP)
#define TOOLSPARSERSSYNTEL_HEADERS_HPP

#include "ToolsCommon/Parsers/SyntaxElements/ToolsParsersSyntEl_AlternativeList.hpp"
#include "ToolsCommon/Parsers/SyntaxElements/ToolsParsersSyntEl_Concatenation.hpp"
#include "ToolsCommon/Parsers/SyntaxElements/ToolsParsersSyntEl_Keyword.hpp"
#include "ToolsCommon/Parsers/SyntaxElements/ToolsParsersSyntEl_MultipleValueVariable.hpp"
#include "ToolsCommon/Parsers/SyntaxElements/ToolsParsersSyntEl_Option.hpp"
#include "ToolsCommon/Parsers/SyntaxElements/ToolsParsersSyntEl_ParameterGroup.hpp"
#include "ToolsCommon/Parsers/SyntaxElements/ToolsParsersSyntEl_Repetition.hpp"
#include "ToolsCommon/Parsers/SyntaxElements/ToolsParsersSyntEl_Set.hpp"
#include "ToolsCommon/Parsers/SyntaxElements/ToolsParsersSyntEl_Variable.hpp"

#endif
